You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@click.apache.org by sa...@apache.org on 2009/05/17 21:25:56 UTC

svn commit: r775741 - /incubator/click/trunk/click/extras/src/org/apache/click/extras/prototype/CalendarField.java

Author: sabob
Date: Sun May 17 19:25:55 2009
New Revision: 775741

URL: http://svn.apache.org/viewvc?rev=775741&view=rev
Log:
renamed method to renderCalendarButton

Modified:
    incubator/click/trunk/click/extras/src/org/apache/click/extras/prototype/CalendarField.java

Modified: incubator/click/trunk/click/extras/src/org/apache/click/extras/prototype/CalendarField.java
URL: http://svn.apache.org/viewvc/incubator/click/trunk/click/extras/src/org/apache/click/extras/prototype/CalendarField.java?rev=775741&r1=775740&r2=775741&view=diff
==============================================================================
--- incubator/click/trunk/click/extras/src/org/apache/click/extras/prototype/CalendarField.java (original)
+++ incubator/click/trunk/click/extras/src/org/apache/click/extras/prototype/CalendarField.java Sun May 17 19:25:55 2009
@@ -352,7 +352,7 @@
         }
 
         super.render(buffer);
-        renderCalendar(buffer);
+        renderCalendarButton(buffer);
 
         if (help != null) {
             buffer.append(help);
@@ -362,11 +362,12 @@
     // ------------------------------------------------------ Protected Methods
 
     /**
      * Render the calendar HTML representation to the buffer.
      *
      * @param buffer the buffer to render the calendar HTML representation to
      */
-    protected void renderCalendar(HtmlStringBuffer buffer) {
+    protected void renderCalendarButton(HtmlStringBuffer buffer) {
 
         if (!isReadonly() && !isDisabled()) {
             Context context = getContext();
@@ -362,11 +362,12 @@
 
     /**
-     * Render the calendar HTML representation to the buffer.
+     * Render the calendar button HTML representation to the buffer.
      *
@@ -362,11 +362,12 @@
      *
-     * @param buffer the buffer to render the calendar HTML representation to
+     * @param buffer the buffer to render the calendar button HTML
+     * representation to
      */